@@ -8,6 +8,7 @@ import logging
 import threading
 import multiprocessing
 
+from email.utils import parseaddr, formataddr
 from configparser import ConfigParser
 
 try:
@@ -94,7 +95,7 @@ class Config:
         "dbpath = /tmp/isso.db",
         "host = ",
         "max-age = 15m",
-        "notify = ",
+        "notify = stdout",
         "[moderation]",
         "enabled = false",
         "purge-after = 30d",
@@ -145,6 +146,9 @@ class Config:
                     logger.info("Your `session-key` has been stored in the "
                                 "database itself, this option is now unused")
 
+        if not parseaddr(rv.get("smtp", "from"))[0]:
+            rv.set("smtp", "from", formataddr((u"Ich schrei sonst!", rv.get("smtp", "from"))))
+
         return rv
 
 
